@@ -6,10 +6,12 @@ use File::ShareDir qw/dist_dir/;
 use Path::Tiny qw/path/;
 use Text::MicroTemplate qw/render_mt/;
 use Plack::Runner;
+use Pod::Usage;
 
 my $_plack_port = 5000;
 my $_dry_run = 0;
 my $_theme_path = '';
+my $_transition = 'default';
 
 sub run {
     my ($self, @args) = @_;
@@ -17,16 +19,20 @@ sub run {
     GetOptionsFromArray( \@args, 
                          'p|port=s' => \$_plack_port,
                          'theme=s' => \$_theme,
-                         'dry-run' => \$_dry_run );
+                         'transition=s' => \$_transition,
+                         '_dry-run' => \$_dry_run );
     my $filename = shift @args;
-    die "Markdown filename is required in args.\n" unless $filename;
-    die "File: $filename is not found.\n" unless path($filename)->exists;
-    $_theme_path = path('.', $_theme) if $_theme;
 
+    if( !$filename || !path($filename)->exists ) {
+        pod2usage({-input => __FILE__, -verbose => 2, -output => \*STDERR});
+    }
+
+    $_theme_path = path('.', $_theme) if $_theme;
     my $html = $self->render($filename);
     my $app = $self->app($html);
     my $runner = Plack::Runner->new();
     $runner->parse_options("--port=$_plack_port");
+    $runner->parse_options("--no-default-middleware");
     $runner->run($app) if !$_dry_run;
 }
 
@@ -35,7 +41,7 @@ sub render {
     my $template_dir = $self->share_path([qw/share templates/]);
     my $template = $template_dir->child('slide.html.mt');
     my $content = $template->slurp_utf8();
-    my $html = render_mt($content, $filename, $_theme_path)->as_string();
+    my $html = render_mt($content, $filename, $_theme_path, $_transition)->as_string();
     return $html;
 }
 
@@ -49,25 +55,24 @@ sub app {
                 ['Content-Type' => 'text/html', 'Content-Length' => length $html],
                 [$html]
             ];
+        };
+        my $path;
+        if($env->{PATH_INFO} =~ m!\.(?:md|mkdn)$!) {
+            $path = path('.', $env->{PATH_INFO});
         }else{
-            my $path;
-            if($env->{PATH_INFO} =~ m!\.(?:md|mkdn)$!) {
-                $path = path('.', $env->{PATH_INFO});
-            }else{
-                if($_theme_path && $env->{PATH_INFO} =~ m!$_theme_path$!){
-                    if($_theme_path->exists) {
-                        $path = path('.', $_theme_path);
-                    }else{
-                        my $revealjs_theme_path = $self->share_path([qw/share revealjs css theme/]);
-                        $path = $revealjs_theme_path->child($_theme_path->basename);
-                    }
+            if($_theme_path && $env->{PATH_INFO} =~ m!$_theme_path$!){
+                if($_theme_path->exists) {
+                    $path = path('.', $_theme_path);
                 }else{
-                    my $revealjs_dir = $self->share_path([qw/share revealjs/]);
-                    $path = $revealjs_dir->child($env->{PATH_INFO});
+                    my $reveal_theme_path = $self->share_path([qw/share revealjs css theme/]);
+                    $path = $reveal_theme_path->child($_theme_path->basename);
                 }
+            }else{
+                my $reveal_dir = $self->share_path([qw/share revealjs/]);
+                $path = $reveal_dir->child($env->{PATH_INFO});
             }
-            return $self->path_to_res($path);
         }
+        return $self->path_to_res($path);
     };
 }
 
@@ -76,9 +81,8 @@ sub path_to_res {
     if( $path && $path->exists ) {
         my $c = $path->slurp();
         return [200, [ 'Content-Length' => length $c ], [$c]];
-    }else{
-        return [404, [], ['not found.']];
     }
+    return [404, [], ['not found.']];
 }
 
 sub share_path {
@@ -93,3 +97,32 @@ sub share_path {
 
 1;
 
+__END__
+
+=head1 SYNOPSIS
+
+    $ revealup serve -p 5000 markdown.md
+
+=head1 DESCRIPTION
+
+I<serve> commnad makes your markdown texts as a HTTP Web application for slideshow.
+Run C<revealup serve> the with markdown filename and options.
+And with your browser access such url I<http://localhost:5000/>.
+
+Options:
+
+=over 4
+
+=item -p           : HTTP Port Number
+
+=item --theme      : CSS filename or path
+
+=item --transition : default/cube/page/concave/zoom/linear/fade/none
+
+=back
+
+=head1 MORE INFORMATION
+
+    $ perldoc App::revealup
+
+=cut
